@@ -146,8 +146,9 @@ class DateCColumns(urwid.Columns):
         self.contents[old_pos][0].set_styles(
             self.get_styles(self.contents[old_pos][0].date, False))
 
-    def _set_focus_position(self, position):
-        """calls on_date_change before calling super()._set_focus_position"""
+    @urwid.Columns.focus_position.setter
+    def focus_position(self, position: int) -> None:
+        """calls on_date_change before setting super().focus_position"""
         # do not call when building up the interface, lots of potentially
         # expensive calls made here
         if self._init:
@@ -157,12 +158,12 @@ class DateCColumns(urwid.Columns):
             self.contents[position][0].set_styles(
                 self.get_styles(self.contents[position][0].date, True))
             self.on_date_change(self.contents[position][0].date)
-        super()._set_focus_position(position)
+        urwid.Columns.focus_position.fset(self, position)
 
     def set_focus_date(self, a_date):
         for num, day in enumerate(self.contents[1:8], 1):
             if day[0].date == a_date:
-                self._set_focus_position(num)
+                self.focus_position = num
                 return None
         raise ValueError('%s not found in this week' % a_date)
 
@@ -175,13 +176,6 @@ class DateCColumns(urwid.Columns):
                 return num
         raise ValueError('%s not found in this week' % a_date)
 
-    focus_position = property(
-        urwid.Columns._get_focus_position,
-        _set_focus_position,
-        doc=('Index of child widget in focus. Raises IndexError if read when '
-             'CColumns is empty, or when set to an invalid index.')
-    )
-
     def keypress(self, size, key):
         """only leave calendar area on pressing 'tab' or 'enter'"""
 
@@ -387,7 +381,7 @@ class CalendarWalker(urwid.SimpleFocusListWalker):
         """
         row, column = self.get_date_pos(a_day)
         self.set_focus(row)
-        self[self.focus]._set_focus_position(column)
+        self[self.focus].focus_position = (column)
 
     @property
     def earliest_date(self):
@@ -424,14 +418,14 @@ class CalendarWalker(urwid.SimpleFocusListWalker):
         # will lead to an autoprepend which will f*ck up our estimation,
         # therefore better autoprepending anyway, even if it might not be
         # necessary
-        if new_focus <= 1:
+        while new_focus <= 1:
             self._autoprepend()
             week_diff = int((self.focus_date - a_day).days / 7)
             new_focus = self.focus - week_diff
         for offset in [0, -1, 1]:  # we might be off by a week
             row = new_focus + offset
             try:
-                if row >= len(self):
+                while row >= len(self):
                     self._autoextend()
                 column = self[row].get_date_column(a_day)
                 return row, column
