@@ -24,10 +24,20 @@ import datetime as dt
 import urwid
 
 from ..utils import get_weekday_occurrence, get_wrapped_text
-from .calendarwidget import CalendarWidget
-from .widgets import (AlarmsEditor, Choice, DateConversionError, DateWidget,
-                      ExtendedEdit, NColumns, NListBox, NPile, PositiveIntEdit,
-                      TimeWidget, ValidatedEdit)
+from .widgets import (
+    AlarmsEditor,
+    CalendarWidget,
+    Choice,
+    DateConversionError,
+    DateWidget,
+    ExtendedEdit,
+    NColumns,
+    NListBox,
+    NPile,
+    PositiveIntEdit,
+    TimeWidget,
+    ValidatedEdit,
+)
 
 
 class StartEnd:
@@ -48,7 +58,7 @@ class CalendarPopUp(urwid.PopUpLauncher):
         self._monthdisplay = monthdisplay
         self._firstweekday = firstweekday
         self._keybindings = {} if keybindings is None else keybindings
-        self.__super.__init__(widget)
+        super().__init__(widget)
 
     def keypress(self, size, key):
         if key == 'enter':
@@ -95,7 +105,7 @@ class DateEdit(urwid.WidgetWrap):
             weeknumbers=False, firstweekday=0, monthdisplay='firstday',
             keybindings=None,
     ):
-        datewidth = len(startdt.strftime(dateformat)) + 1
+        datewidth = len(startdt.strftime(dateformat))
         self._dateformat = dateformat
         if startdt is None:
             startdt = dt.date.today()
@@ -514,7 +524,7 @@ class EventEditor(urwid.WidgetWrap):
             self.event.increment_sequence()
             if self.event.etag is None:  # has not been saved before
                 self.event.calendar = self.calendar_chooser.active['name']
-                self.collection.new(self.event)
+                self.collection.insert(self.event)
             elif self.calendar_chooser.changed:
                 self.collection.change_collection(
                     self.event,
