@@ -431,6 +431,14 @@ def test_no_default_new(runner):
             "please provide one explicitly.") in result.output
     assert result.exit_code == 2
 
+def test_print_bad_ics(runner):
+    """Attempt to print a .ics that is malformed, but does not have a DST-related error."""
+    runner = runner()
+    result = runner.invoke(main_khal, ['printics', _get_ics_filepath('non_dst_error')])
+    assert result.exception
+    expected = ValueError("Invalid iCalendar duration: PT-2H")
+    assert expected.__class__ == result.exception.__class__
+    assert expected.args == result.exception.args
 
 def test_import(runner, monkeypatch):
     runner = runner()
@@ -554,19 +562,26 @@ def test_color_option(runner):
 
 
 def choices(dateformat=0, timeformat=0,
-            parse_vdirsyncer_conf=True,
-            create_vdir=False,
             default_calendar='',
+            calendar_option=0,
+            accept_vdirsyncer_dir=True,
+            vdir='',
+            caldav_url='', caldav_user='', caldav_pw='',
             write_config=True):
     """helper function to generate input for testing `configure`"""
     confirm = {True: 'y', False: 'n'}
 
     out = [
-        str(dateformat), str(timeformat),
-        confirm[parse_vdirsyncer_conf],
+        str(dateformat), str(timeformat), str(calendar_option),
     ]
-    if not parse_vdirsyncer_conf:
-        out.append(confirm[create_vdir])
+    if calendar_option == 1:
+        out.append(confirm[accept_vdirsyncer_dir])
+        if not accept_vdirsyncer_dir:
+            out.append(vdir)
+    elif calendar_option == 2:
+        out.append(caldav_url)
+        out.append(caldav_user)
+        out.append(caldav_pw)
     out.append(default_calendar)
     out.append(confirm[write_config])
     out.append('')
@@ -628,19 +643,11 @@ def test_configure_command(runner):
     with open(str(runner.config_file)) as f:
         actual_config = ''.join(f.readlines())
 
-    assert actual_config == '''[calendars]
+    assert actual_config == f'''[calendars]
 
-[[events_local]]
-path = ~/.local/share/calendars/events/*
-type = discover
-
-[[home_calendar_local]]
-path = ~/.local/share/calendars/home/*
-type = discover
-
-[[home_contacts_local]]
-path = ~/.local/share/contacts/*
-type = discover
+[[private]]
+path = {runner.tmpdir}/vdirs/khal/calendars/private
+type = calendar
 
 [locale]
 timeformat = %H:%M
@@ -650,7 +657,7 @@ datetimeformat = %Y-%m-%d %H:%M
 longdatetimeformat = %Y-%m-%d %H:%M
 
 [default]
-default_calendar = events_local
+default_calendar = private
 '''
 
     # if aborting, no config file should be written
@@ -721,7 +728,7 @@ def test_configure_command_create_vdir(runner):
 
     result = runner.invoke(
         main_khal, ['configure'],
-        input=choices(parse_vdirsyncer_conf=False, create_vdir=True),
+        input=choices(),
     )
     assert f'Successfully wrote configuration to {str(runner.config_file)}' in result.output
     assert result.exit_code == 0
@@ -750,7 +757,7 @@ default_calendar = private
     runner.config_file.remove()
     result = runner.invoke(
         main_khal, ['configure'],
-        input=choices(parse_vdirsyncer_conf=False, create_vdir=True),
+        input=choices(),
     )
     assert f'Successfully wrote configuration to {str(runner.config_file)}' in result.output
     assert result.exit_code == 0
@@ -787,7 +794,7 @@ def test_configure_command_cannot_create_vdir(runner):
     os.mkdir(str(runner.xdg_data_home), mode=555)
     result = runner.invoke(
         main_khal, ['configure'],
-        input=choices(parse_vdirsyncer_conf=False, create_vdir=True),
+        input=choices(),
     )
     assert 'Exiting' in result.output
     assert result.exit_code == 1
@@ -795,18 +802,6 @@ def test_configure_command_cannot_create_vdir(runner):
     cleanup([runner.xdg_data_home])
 
 
-def test_configure_no_vdir(runner):
-    runner = runner()
-    runner.config_file.remove()
-    result = runner.invoke(
-        main_khal, ['configure'],
-        input=choices(parse_vdirsyncer_conf=False, create_vdir=False),
-    )
-    assert 'khal will not be usable like this' in result.output
-    assert result.exit_code == 0
-    assert not result.exception
-
-
 def test_edit(runner):
     runner = runner()
     result = runner.invoke(main_khal, ['list'])
