@@ -3,23 +3,60 @@ import os
 from time import sleep
 
 import pytest
-import pytz
 
+from khal.custom_types import CalendarConfiguration
 from khal.khalendar import CalendarCollection
 from khal.khalendar.vdir import Vdir
 
-from .utils import LOCALE_BERLIN, cal1, example_cals
+from .utils import LOCALE_BERLIN, CollVdirType, cal1, example_cals
 
 
 @pytest.fixture
-def coll_vdirs(tmpdir):
+def metavdirs(tmpdir):
+    tmpdir = str(tmpdir)
+    dirstructure = [
+        '/cal1/public/',
+        '/cal1/private/',
+        '/cal2/public/',
+        '/cal3/public/',
+        '/cal3/work/',
+        '/cal3/home/',
+        '/cal4/cfgcolor/',
+        '/cal4/dircolor/',
+        '/cal4/cfgcolor_again/',
+        '/cal4/cfgcolor_once_more/',
+        '/singlecollection/',
+    ]
+    for one in dirstructure:
+        os.makedirs(tmpdir + one)
+    filestructure = [
+        ('/cal1/public/displayname', 'my calendar'),
+        ('/cal1/public/color', 'dark blue'),
+        ('/cal1/private/displayname', 'my private calendar'),
+        ('/cal1/private/color', '#FF00FF'),
+        ('/cal4/dircolor/color', 'dark blue'),
+    ]
+    for filename, content in filestructure:
+        with open(tmpdir + filename, 'w') as metafile:
+            metafile.write(content)
+    return tmpdir
+
+
+@pytest.fixture
+def coll_vdirs(tmpdir) -> CollVdirType:
     calendars, vdirs = {}, {}
     for name in example_cals:
         path = str(tmpdir) + '/' + name
         os.makedirs(path, mode=0o770)
         readonly = True if name == 'a_calendar' else False
-        calendars[name] = {'name': name, 'path': path, 'color': 'dark blue',
-                           'readonly': readonly, 'unicode_symbols': True}
+        calendars[name] = CalendarConfiguration(
+            name=name,
+            path=path,
+            readonly=readonly,
+            color='dark blue',
+            priority=10,
+            ctype='calendar',
+        )
         vdirs[name] = Vdir(path, '.ics')
     coll = CalendarCollection(calendars=calendars, dbpath=':memory:', locale=LOCALE_BERLIN)
     coll.default_calendar_name = cal1
@@ -106,13 +143,6 @@ def sleep_time(tmpdir_factory):
     )
 
 
-@pytest.fixture(scope='session')
-def pytz_version():
-    """Return the version of pytz as a tuple."""
-    year, month = pytz.__version__.split('.')
-    return int(year), int(month)
-
-
 @pytest.fixture
 def fix_caplog(monkeypatch):
     """Temporarily undoes the logging setup by click-log such that the caplog fixture can be used"""
