@@ -3,13 +3,24 @@ import datetime as dt
 import pytest
 import pytz
 from freezegun import freeze_time
+from hypothesis import event, given
+from hypothesis.strategies import datetimes
 from icalendar import Parameters, vCalAddress, vRecur, vText
+from packaging import version
 
-from khal.khalendar.event import (AllDayEvent, Event, FloatingEvent,
-                                  LocalizedEvent, create_timezone)
+from khal.khalendar.event import AllDayEvent, Event, FloatingEvent, LocalizedEvent, create_timezone
 
-from .utils import (BERLIN, BOGOTA, GMTPLUS3, LOCALE_BERLIN, LOCALE_BOGOTA,
-                    LOCALE_MIXED, NEW_YORK, _get_text, normalize_component)
+from .utils import (
+    BERLIN,
+    BOGOTA,
+    GMTPLUS3,
+    LOCALE_BERLIN,
+    LOCALE_BOGOTA,
+    LOCALE_MIXED,
+    NEW_YORK,
+    _get_text,
+    normalize_component,
+)
 
 EVENT_KWARGS = {'calendar': 'foobar', 'locale': LOCALE_BERLIN}
 
@@ -339,16 +350,22 @@ def test_event_dt_long():
         '09.04.2014 09:30-12.04.2014 10:30 An Event\x1b[0m'
 
 
-def test_event_no_dst(pytz_version):
+def test_event_no_dst():
     """test the creation of a corect VTIMEZONE for timezones with no dst"""
     event_no_dst = _get_text('event_no_dst')
     cal_no_dst = _get_text('cal_no_dst')
     event = Event.fromString(event_no_dst, calendar='foobar', locale=LOCALE_BOGOTA)
-    if pytz_version > (2017, 1):
-        cal_no_dst = cal_no_dst.replace(
-            'TZNAME:COT',
-            'RDATE:20380118T221407\r\nTZNAME:-05'
-        )
+    if version.parse(pytz.__version__) > version.Version('2017.1'):
+        if version.parse(pytz.__version__) < version.Version('2022.7'):
+            cal_no_dst = cal_no_dst.replace(
+                'TZNAME:COT',
+                'RDATE:20380118T221407\r\nTZNAME:-05'
+            )
+        else:
+            cal_no_dst = cal_no_dst.replace(
+                'TZNAME:COT',
+                'TZNAME:-05'
+            )
 
     assert normalize_component(event.raw) == normalize_component(cal_no_dst)
     assert event.format(SEARCH_FORMAT, dt.date(2014, 4, 10)) == \
@@ -367,7 +384,7 @@ def test_event_raw_UTC():
         '''SUMMARY:An Event''',
         '''DTSTART:20140409T093000Z''',
         '''DTEND:20140409T103000Z''',
-        '''DTSTAMP;VALUE=DATE-TIME:20140401T234817Z''',
+        '''DTSTAMP:20140401T234817Z''',
         '''UID:V042MJ8B3SJNFXQOJL6P53OFMHJE8Z3VZWOU''',
         '''END:VEVENT''',
         '''END:VCALENDAR\r\n'''])
@@ -536,7 +553,7 @@ def test_create_timezone_static():
         b'BEGIN:VTIMEZONE',
         b'TZID:Etc/GMT-8',
         b'BEGIN:STANDARD',
-        b'DTSTART;VALUE=DATE-TIME:16010101T000000',
+        b'DTSTART:16010101T000000',
         b'RDATE:16010101T000000',
         b'TZNAME:Etc/GMT-8',
         b'TZOFFSETFROM:+0800',
@@ -557,7 +574,7 @@ PRODID:-//PIMUTILS.ORG//NONSGML khal / icalendar //EN
 BEGIN:VTIMEZONE
 TZID:Etc/GMT+3
 BEGIN:STANDARD
-DTSTART;VALUE=DATE-TIME:16010101T000000
+DTSTART:16010101T000000
 RDATE:16010101T000000
 TZNAME:Etc/GMT+3
 TZOFFSETFROM:-0300
@@ -566,9 +583,9 @@ END:STANDARD
 END:VTIMEZONE
 BEGIN:VEVENT
 SUMMARY:An Event
-DTSTART;TZID=Etc/GMT+3;VALUE=DATE-TIME:20140409T093000
-DTEND;TZID=Etc/GMT+3;VALUE=DATE-TIME:20140409T103000
-DTSTAMP;VALUE=DATE-TIME:20140401T234817Z
+DTSTART;TZID=Etc/GMT+3:20140409T093000
+DTEND;TZID=Etc/GMT+3:20140409T103000
+DTSTAMP:20140401T234817Z
 UID:V042MJ8B3SJNFXQOJL6P53OFMHJE8Z3VZWOU
 END:VEVENT
 END:VCALENDAR"""
@@ -617,15 +634,33 @@ def test_create_timezone_in_future():
                 b'BEGIN:VTIMEZONE',
                 b'TZID:Europe/Amsterdam',
                 b'BEGIN:STANDARD',
-                b'DTSTART;VALUE=DATE-TIME:20211031T020000',
+                b'DTSTART:20211031T020000',
                 b'TZNAME:CET',
                 b'TZOFFSETFROM:+0200',
                 b'TZOFFSETTO:+0100',
                 b'END:STANDARD',
                 b'BEGIN:DAYLIGHT',
-                b'DTSTART;VALUE=DATE-TIME:20220327T030000',
+                b'DTSTART:20220327T030000',
                 b'TZNAME:CEST',
                 b'TZOFFSETFROM:+0100',
                 b'TZOFFSETTO:+0200',
                 b'END:DAYLIGHT',
                 b'END:VTIMEZONE']
+
+
+now = dt.datetime.now()
+min_value = now - dt.timedelta(days=3560)
+max_value = now + dt.timedelta(days=3560)
+AMSTERDAM = pytz.timezone('Europe/Amsterdam')
+
+
+@given(datetimes(min_value=min_value, max_value=max_value),
+       datetimes(min_value=min_value, max_value=max_value))
+def test_timezone_creation_with_arbitrary_dates(freeze_ts, event_time):
+    """test if for arbitrary dates from the current date we produce a valid VTIMEZONE"""
+    event(f'freeze_ts == event_time: {freeze_ts == event_time}')
+    with freeze_time(freeze_ts):
+        vtimezone = create_timezone(AMSTERDAM, event_time).to_ical().decode('utf-8')
+    assert len(vtimezone) > 14
+    assert 'BEGIN:STANDARD' in vtimezone
+    assert 'BEGIN:DAYLIGHT' in vtimezone
