@@ -16,8 +16,20 @@ from khal.khalendar.event import Event
 from khal.khalendar.vdir import Item
 
 from . import utils
-from .utils import (BERLIN, LOCALE_BERLIN, LOCALE_SYDNEY, LONDON, SYDNEY,
-                    DumbItem, _get_text, cal1, cal2, cal3, normalize_component)
+from .utils import (
+    BERLIN,
+    LOCALE_BERLIN,
+    LOCALE_SYDNEY,
+    LONDON,
+    SYDNEY,
+    CollVdirType,
+    DumbItem,
+    _get_text,
+    cal1,
+    cal2,
+    cal3,
+    normalize_component,
+)
 
 today = dt.date.today()
 yesterday = today - dt.timedelta(days=1)
@@ -49,9 +61,9 @@ class TestCalendar:
 
     def test_new_event(self, coll_vdirs):
         coll, vdirs = coll_vdirs
-        event = coll.new_event(event_today, cal1)
+        event = coll.create_event_from_ics(event_today, cal1)
         assert event.calendar == cal1
-        coll.new(event)
+        coll.insert(event)
         events = list(coll.get_events_on(today))
         assert len(events) == 1
         assert events[0].color == 'dark blue'
@@ -102,11 +114,11 @@ class TestVdirsyncerCompat:
         event = Event.fromString(_get_text('event_d'), calendar=cal1, locale=LOCALE_BERLIN)
         assert event.etag is None
         assert event.href is None
-        coll.new(event)
+        coll.insert(event)
         assert event.etag is not None
         assert event.href == 'V042MJ8B3SJNFXQOJL6P53OFMHJE8Z3VZWOU.ics'
         event = Event.fromString(event_today, calendar=cal1, locale=LOCALE_BERLIN)
-        coll.new(event)
+        coll.insert(event)
         hrefs = sorted(href for href, etag in coll._backend.list(cal1))
         assert {str(coll.get_event(href, calendar=cal1).uid) for href in hrefs} == {
             'uid3@host1.com',
@@ -156,7 +168,7 @@ class TestCollection:
     def test_insert(self, coll_vdirs):
         """insert a localized event"""
         coll, vdirs = coll_vdirs
-        coll.new(
+        coll.insert(
             Event.fromString(_get_text('event_dt_simple'), calendar=cal1, locale=LOCALE_BERLIN),
             cal1)
         events = list(coll.get_localized(self.astart_berlin, self.aend_berlin))
@@ -178,7 +190,7 @@ class TestCollection:
         """insert a floating event"""
         coll, vdirs = coll_vdirs
         event = Event.fromString(_get_text('event_d'), calendar=cal1, locale=LOCALE_BERLIN)
-        coll.new(event, cal1)
+        coll.insert(event, cal1)
         events = list(coll.get_events_on(aday))
         assert len(events) == 1
         assert events[0].calendar == cal1
@@ -191,7 +203,7 @@ class TestCollection:
     def test_insert_d_no_value(self, coll_vdirs):
         """insert a date event with no VALUE=DATE option"""
         coll, vdirs = coll_vdirs
-        coll.new(
+        coll.insert(
             Event.fromString(
                 _get_text('event_d_no_value'), calendar=cal1, locale=LOCALE_BERLIN),
             cal1)
@@ -209,17 +221,18 @@ class TestCollection:
         event = Event.fromString(
             _get_text('event_dt_simple'), href='xyz.ics', calendar=cal1, locale=LOCALE_BERLIN,
         )
-        coll.new(event, cal1)
+        coll.insert(event, cal1)
         event_from_db = coll.get_event(SIMPLE_EVENT_UID + '.ics', cal1)
         with freeze_time('2016-1-1'):
             assert normalize_component(event_from_db.raw) == \
                 normalize_component(_get_text('event_dt_simple_inkl_vtimezone'))
+        assert event_from_db.etag
 
     def test_change(self, coll_vdirs):
         """moving an event from one calendar to another"""
         coll, vdirs = coll_vdirs
         event = Event.fromString(_get_text('event_dt_simple'), calendar=cal1, locale=LOCALE_BERLIN)
-        coll.new(event, cal1)
+        coll.insert(event, cal1)
         event = list(coll.get_events_on(aday))[0]
         assert event.calendar == cal1
 
@@ -233,7 +246,7 @@ class TestCollection:
         coll, vdirs = coll_vdirs
         event = Event.fromString(
             _get_text('event_dt_simple'), calendar=cal1, locale=LOCALE_BERLIN)
-        coll.new(event, cal1)
+        coll.insert(event, cal1)
         events = coll.get_events_on(aday)
         event = list(events)[0]
         event.update_summary('really simple event')
@@ -249,11 +262,11 @@ class TestCollection:
         coll, vdirs = coll_vdirs
         bday = dt.datetime.combine(aday, dt.time.min)
         anend = bday + dt.timedelta(hours=1)
-        event = icalendar_helpers.new_event(
+        event = icalendar_helpers.new_vevent(
             dtstart=bday, dtend=anend, summary="hi", timezone=utils.BERLIN,
             locale=LOCALE_BERLIN,
         )
-        event = coll.new_event(event.to_ical(), coll.default_calendar_name)
+        event = coll.create_event_from_ics(event.to_ical(), coll.default_calendar_name)
         assert event.allday is False
 
     def test_modify_readonly_calendar(self, coll_vdirs):
@@ -263,7 +276,7 @@ class TestCollection:
         event = Event.fromString(_get_text('event_dt_simple'), calendar=cal1, locale=LOCALE_BERLIN)
 
         with pytest.raises(khal.khalendar.exceptions.ReadOnlyCalendarError):
-            coll.new(event, cal1)
+            coll.insert(event, cal1)
         with pytest.raises(khal.khalendar.exceptions.ReadOnlyCalendarError):
             # params don't really matter here
             coll.delete('href', 'eteg', cal1)
@@ -273,11 +286,11 @@ class TestCollection:
         assert len(list(coll.search('Event'))) == 0
         event = Event.fromString(
             _get_text('event_dt_simple'), calendar=cal1, locale=LOCALE_BERLIN)
-        coll.new(event, cal1)
+        coll.insert(event, cal1)
         assert len(list(coll.search('Event'))) == 1
         event = Event.fromString(
             _get_text('event_dt_floating'), calendar=cal1, locale=LOCALE_BERLIN)
-        coll.new(event, cal1)
+        coll.insert(event, cal1)
         assert len(list(coll.search('Search for me'))) == 1
         assert len(list(coll.search('Event'))) == 2
 
@@ -288,7 +301,7 @@ class TestCollection:
         assert len(list(coll.search('Event'))) == 0
         event = Event.fromString(
             _get_text('event_dt_recuid_no_master'), calendar=cal1, locale=LOCALE_BERLIN)
-        coll.new(event, cal1)
+        coll.insert(event, cal1)
         assert len(list(coll.search('Event'))) == 1
 
     def test_search_recurrence_id_only_multi(self, coll_vdirs):
@@ -298,7 +311,7 @@ class TestCollection:
         assert len(list(coll.search('Event'))) == 0
         event = Event.fromString(
             _get_text('event_dt_multi_recuid_no_master'), calendar=cal1, locale=LOCALE_BERLIN)
-        coll.new(event, cal1)
+        coll.insert(event, cal1)
         events = sorted(coll.search('Event'))
         assert len(events) == 2
         assert events[0].format(
@@ -314,9 +327,9 @@ class TestCollection:
             _get_text('event_dt_simple'), calendar=cal1, locale=LOCALE_BERLIN)
         event2 = Event.fromString(
             _get_text('event_dt_simple'), calendar=cal2, locale=LOCALE_BERLIN)
-        coll.new(event1, cal1)
+        coll.insert(event1, cal1)
         sleep(sleep_time)  # make sure the etags are different
-        coll.new(event2, cal2)
+        coll.insert(event2, cal2)
         etag1 = list(vdirs[cal1].list())[0][1]
         etag2 = list(vdirs[cal2].list())[0][1]
         events = list(coll.get_localized(self.astart_berlin, self.aend_berlin))
@@ -328,13 +341,37 @@ class TestCollection:
             if event.calendar == cal2:
                 assert event.etag == etag2
 
+    def test_delete_recuid(self, coll_vdirs: CollVdirType):
+        """Testing if we can delete a recuid (add it to exdate)"""
+        coll, _ = coll_vdirs
+        event_str = _get_text('event_rrule_recuid')
+        event = Event.fromString(event_str, calendar=cal1, locale=LOCALE_BERLIN)
+        coll.insert(event, cal1)
+        event = coll.get_event('event_rrule_recurrence_id.ics', cal1)
+
+        event = coll.delete_instance(
+            'event_rrule_recurrence_id.ics',
+            event.etag,
+            calendar=cal1,
+            rec_id=BERLIN.localize(dt.datetime(2014, 7, 14, 5)),
+        )
+        assert 'EXDATE;TZID=Europe/Berlin:20140714T050000' in event.raw.split()
+
+        event = coll.delete_instance(
+            'event_rrule_recurrence_id.ics',
+            event.etag,
+            calendar=cal1,
+            rec_id=BERLIN.localize(dt.datetime(2014, 7, 21, 5)),
+        )
+        assert 'EXDATE;TZID=Europe/Berlin:20140714T050000,20140721T050000' in event.raw.split()
+
     def test_invalid_timezones(self, coll_vdirs):
         """testing if we can delete any of two events in two different
         calendars with the same filename"""
         coll, vdirs = coll_vdirs
         event = Event.fromString(
             _get_text('invalid_tzoffset'), calendar=cal1, locale=LOCALE_BERLIN)
-        coll.new(event, cal1)
+        coll.insert(event, cal1)
         events = sorted(coll.search('Event'))
         assert len(events) == 1
         assert events[0].format('{start} {end} {title}', dt.date.today()) == \
@@ -434,7 +471,7 @@ def test_default_calendar(coll_vdirs, sleep_time):
     """test if an update to the vdir is detected by the CalendarCollection"""
     coll, vdirs = coll_vdirs
     vdir = vdirs['foobar']
-    event = coll.new_event(event_today, 'foobar')
+    event = coll.create_event_from_ics(event_today, 'foobar')
 
     assert len(list(coll.get_events_on(today))) == 0
 
@@ -460,7 +497,7 @@ def test_default_calendar(coll_vdirs, sleep_time):
 def test_only_update_old_event(coll_vdirs, monkeypatch, sleep_time):
     coll, vdirs = coll_vdirs
 
-    href_one, etag_one = vdirs[cal1].upload(coll.new_event(dedent("""
+    href_one, etag_one = vdirs[cal1].upload(coll.create_event_from_ics(dedent("""
     BEGIN:VEVENT
     UID:meeting-one
     DTSTART;VALUE=DATE:20140909
@@ -471,7 +508,7 @@ def test_only_update_old_event(coll_vdirs, monkeypatch, sleep_time):
 
     sleep(sleep_time)  # Make sure we get a new etag for meeting-two
 
-    href_two, etag_two = vdirs[cal1].upload(coll.new_event(dedent("""
+    href_two, etag_two = vdirs[cal1].upload(coll.create_event_from_ics(dedent("""
     BEGIN:VEVENT
     UID:meeting-two
     DTSTART;VALUE=DATE:20140910
@@ -493,7 +530,7 @@ def test_only_update_old_event(coll_vdirs, monkeypatch, sleep_time):
         return old_update_vevent(href, calendar)
     monkeypatch.setattr(coll, '_update_vevent', _update_vevent)
 
-    href_three, etag_three = vdirs[cal1].upload(coll.new_event(dedent("""
+    href_three, etag_three = vdirs[cal1].upload(coll.create_event_from_ics(dedent("""
     BEGIN:VEVENT
     UID:meeting-three
     DTSTART;VALUE=DATE:20140911
