@@ -5,14 +5,24 @@ import pytest
 from freezegun import freeze_time
 
 from khal.exceptions import DateTimeParseError, FatalError
-from khal.icalendar import new_event
-from khal.parse_datetime import (construct_daynames, eventinfofstr,
-                                 guessdatetimefstr, guessrangefstr,
-                                 guesstimedeltafstr, timedelta2str,
-                                 weekdaypstr)
+from khal.icalendar import new_vevent
+from khal.parse_datetime import (
+    construct_daynames,
+    eventinfofstr,
+    guessdatetimefstr,
+    guessrangefstr,
+    guesstimedeltafstr,
+    timedelta2str,
+    weekdaypstr,
+)
 
-from .utils import (LOCALE_BERLIN, LOCALE_FLOATING, LOCALE_NEW_YORK,
-                    _replace_uid, normalize_component)
+from .utils import (
+    LOCALE_BERLIN,
+    LOCALE_FLOATING,
+    LOCALE_NEW_YORK,
+    _replace_uid,
+    normalize_component,
+)
 
 
 def _create_testcases(*cases):
@@ -27,10 +37,11 @@ def _construct_event(info, locale,
     info = eventinfofstr(' '.join(info), locale,
                          dt.timedelta(days=1),
                          dt.timedelta(hours=1),
-                         adjust_reasonably=True, localize=False)
+                         adjust_reasonably=True,
+                         )
     if description is not None:
         info["description"] = description
-    event = new_event(
+    event = new_vevent(
         locale=locale, location=location,
         categories=categories, repeat=repeat, until=until,
         alarms=alarm,
@@ -51,7 +62,7 @@ def _create_vevent(*args):
          ('SUMMARY', 'SUMMARY:Äwesöme Event'),
          ('DTSTART', 'DTSTART;VALUE=DATE:20131025'),
          ('DTEND', 'DTEND;VALUE=DATE:20131026'),
-         ('DTSTAMP', 'DTSTAMP;VALUE=DATE-TIME:20140216T120000Z'),
+         ('DTSTAMP', 'DTSTAMP:20140216T120000Z'),
          ('UID', 'UID:E41JRQX2DB4P1AQZI86BAT7NHPBHPRIIHQKA')])
 
     for row in args:
@@ -330,55 +341,55 @@ test_set_format_de = _create_testcases(
     # start and end date same, no explicit end date given
     ('25.10.2013 18:00 20:00 Äwesöme Event',
      _create_vevent(
-         'DTSTART;TZID=Europe/Berlin;VALUE=DATE-TIME:20131025T180000',
-         'DTEND;TZID=Europe/Berlin;VALUE=DATE-TIME:20131025T200000')),
+         'DTSTART;TZID=Europe/Berlin:20131025T180000',
+         'DTEND;TZID=Europe/Berlin:20131025T200000')),
 
     # start and end date same, ends 24:00 which should be 00:00 (start) of next
     # day
     ('25.10.2013 18:00 24:00 Äwesöme Event',
      _create_vevent(
-         'DTSTART;TZID=Europe/Berlin;VALUE=DATE-TIME:20131025T180000',
-         'DTEND;TZID=Europe/Berlin;VALUE=DATE-TIME:20131026T000000')),
+         'DTSTART;TZID=Europe/Berlin:20131025T180000',
+         'DTEND;TZID=Europe/Berlin:20131026T000000')),
 
     # start and end date same, explicit end date (but no year) given
     ('25.10.2013 18:00 26.10. 20:00 Äwesöme Event',
      _create_vevent(
-         'DTSTART;TZID=Europe/Berlin;VALUE=DATE-TIME:20131025T180000',
-         'DTEND;TZID=Europe/Berlin;VALUE=DATE-TIME:20131026T200000')),
+         'DTSTART;TZID=Europe/Berlin:20131025T180000',
+         'DTEND;TZID=Europe/Berlin:20131026T200000')),
 
     ('30.12.2013 18:00 2.1. 20:00 Äwesöme Event',
      _create_vevent(
-         'DTSTART;TZID=Europe/Berlin;VALUE=DATE-TIME:20131230T180000',
-         'DTEND;TZID=Europe/Berlin;VALUE=DATE-TIME:20140102T200000')),
+         'DTSTART;TZID=Europe/Berlin:20131230T180000',
+         'DTEND;TZID=Europe/Berlin:20140102T200000')),
 
     # only start date given (no year, past day and month)
     ('25.01. 18:00 20:00 Äwesöme Event',
      _create_vevent(
-         'DTSTART;TZID=Europe/Berlin;VALUE=DATE-TIME:20150125T180000',
-         'DTEND;TZID=Europe/Berlin;VALUE=DATE-TIME:20150125T200000')),
+         'DTSTART;TZID=Europe/Berlin:20150125T180000',
+         'DTEND;TZID=Europe/Berlin:20150125T200000')),
 
     # date ends next day, but end date not given
     ('25.10.2013 23:00 0:30 Äwesöme Event',
      _create_vevent(
-         'DTSTART;TZID=Europe/Berlin;VALUE=DATE-TIME:20131025T230000',
-         'DTEND;TZID=Europe/Berlin;VALUE=DATE-TIME:20131026T003000')),
+         'DTSTART;TZID=Europe/Berlin:20131025T230000',
+         'DTEND;TZID=Europe/Berlin:20131026T003000')),
 
     ('2.2. 23:00 0:30 Äwesöme Event',
      _create_vevent(
-         'DTSTART;TZID=Europe/Berlin;VALUE=DATE-TIME:20150202T230000',
-         'DTEND;TZID=Europe/Berlin;VALUE=DATE-TIME:20150203T003000')),
+         'DTSTART;TZID=Europe/Berlin:20150202T230000',
+         'DTEND;TZID=Europe/Berlin:20150203T003000')),
 
     # only start datetime given
     ('25.10.2013 06:00 Äwesöme Event',
      _create_vevent(
-         'DTSTART;TZID=Europe/Berlin;VALUE=DATE-TIME:20131025T060000',
-         'DTEND;TZID=Europe/Berlin;VALUE=DATE-TIME:20131025T070000')),
+         'DTSTART;TZID=Europe/Berlin:20131025T060000',
+         'DTEND;TZID=Europe/Berlin:20131025T070000')),
 
     # timezone given
     ('25.10.2013 06:00 America/New_York Äwesöme Event',
      _create_vevent(
-         'DTSTART;TZID=America/New_York;VALUE=DATE-TIME:20131025T060000',
-         'DTEND;TZID=America/New_York;VALUE=DATE-TIME:20131025T070000'))
+         'DTSTART;TZID=America/New_York:20131025T060000',
+         'DTEND;TZID=America/New_York:20131025T070000'))
 )
 
 
@@ -392,8 +403,8 @@ def test_construct_event_format_de():
 test_set_format_us = _create_testcases(
     ('1999/12/31-06:00 Äwesöme Event',
      _create_vevent(
-         'DTSTART;TZID=America/New_York;VALUE=DATE-TIME:19991231T060000',
-         'DTEND;TZID=America/New_York;VALUE=DATE-TIME:19991231T070000')),
+         'DTSTART;TZID=America/New_York:19991231T060000',
+         'DTEND;TZID=America/New_York:19991231T070000')),
 
     ('2014/12/18 2014/12/20 Äwesöme Event',
      _create_vevent('DTSTART;VALUE=DATE:20141218',
@@ -413,20 +424,20 @@ test_set_format_de_complexer = _create_testcases(
     # today
     ('8:00 Äwesöme Event',
      _create_vevent(
-         'DTSTART;TZID=Europe/Berlin;VALUE=DATE-TIME:20140216T080000',
-         'DTEND;TZID=Europe/Berlin;VALUE=DATE-TIME:20140216T090000')),
+         'DTSTART;TZID=Europe/Berlin:20140216T080000',
+         'DTEND;TZID=Europe/Berlin:20140216T090000')),
 
     # today until tomorrow
     ('22:00  1:00 Äwesöme Event',
      _create_vevent(
-         'DTSTART;TZID=Europe/Berlin;VALUE=DATE-TIME:20140216T220000',
-         'DTEND;TZID=Europe/Berlin;VALUE=DATE-TIME:20140217T010000')),
+         'DTSTART;TZID=Europe/Berlin:20140216T220000',
+         'DTEND;TZID=Europe/Berlin:20140217T010000')),
 
     # other timezone
     ('22:00 1:00 Europe/London Äwesöme Event',
      _create_vevent(
-         'DTSTART;TZID=Europe/London;VALUE=DATE-TIME:20140216T220000',
-         'DTEND;TZID=Europe/London;VALUE=DATE-TIME:20140217T010000')),
+         'DTSTART;TZID=Europe/London:20140216T220000',
+         'DTEND;TZID=Europe/London:20140217T010000')),
 
     ('15.06. Äwesöme Event',
      _create_vevent('DTSTART;VALUE=DATE:20140615',
@@ -446,7 +457,7 @@ test_set_leap_year = _create_testcases(
      _create_vevent(
          'DTSTART;VALUE=DATE:20160229',
          'DTEND;VALUE=DATE:20160301',
-         'DTSTAMP;VALUE=DATE-TIME:20160101T202122Z')),
+         'DTSTAMP:20160101T202122Z')),
 )
 
 
@@ -465,15 +476,15 @@ test_set_description = _create_testcases(
     # today
     ('8:00 Äwesöme Event :: this is going to be awesome',
      _create_vevent(
-         'DTSTART;TZID=Europe/Berlin;VALUE=DATE-TIME:20140216T080000',
-         'DTEND;TZID=Europe/Berlin;VALUE=DATE-TIME:20140216T090000',
+         'DTSTART;TZID=Europe/Berlin:20140216T080000',
+         'DTEND;TZID=Europe/Berlin:20140216T090000',
          'DESCRIPTION:this is going to be awesome')),
 
     # today until tomorrow
     ('22:00  1:00 Äwesöme Event :: Will be even better',
      _create_vevent(
-         'DTSTART;TZID=Europe/Berlin;VALUE=DATE-TIME:20140216T220000',
-         'DTEND;TZID=Europe/Berlin;VALUE=DATE-TIME:20140217T010000',
+         'DTSTART;TZID=Europe/Berlin:20140216T220000',
+         'DTEND;TZID=Europe/Berlin:20140217T010000',
          'DESCRIPTION:Will be even better')),
 
     ('15.06. Äwesöme Event :: and again',
@@ -495,8 +506,8 @@ test_set_repeat_floating = _create_testcases(
     # today
     ('8:00 Äwesöme Event',
      _create_vevent(
-         'DTSTART;VALUE=DATE-TIME:20140216T080000',
-         'DTEND;VALUE=DATE-TIME:20140216T090000',
+         'DTSTART:20140216T080000',
+         'DTEND:20140216T090000',
          'DESCRIPTION:please describe the event',
          'RRULE:FREQ=DAILY;UNTIL=20150604T000000')))
 
@@ -518,8 +529,8 @@ test_set_repeat_localized = _create_testcases(
     # today
     ('8:00 Äwesöme Event',
      _create_vevent(
-         'DTSTART;TZID=Europe/Berlin;VALUE=DATE-TIME:20140216T080000',
-         'DTEND;TZID=Europe/Berlin;VALUE=DATE-TIME:20140216T090000',
+         'DTSTART;TZID=Europe/Berlin:20140216T080000',
+         'DTEND;TZID=Europe/Berlin:20140216T090000',
          'DESCRIPTION:please describe the event',
          'RRULE:FREQ=DAILY;UNTIL=20150604T230000Z')))
 
@@ -540,9 +551,9 @@ test_set_alarm = _create_testcases(
     ('8:00 Äwesöme Event',
      ['BEGIN:VEVENT',
       'SUMMARY:Äwesöme Event',
-      'DTSTART;TZID=Europe/Berlin;VALUE=DATE-TIME:20140216T080000',
-      'DTEND;TZID=Europe/Berlin;VALUE=DATE-TIME:20140216T090000',
-      'DTSTAMP;VALUE=DATE-TIME:20140216T120000Z',
+      'DTSTART;TZID=Europe/Berlin:20140216T080000',
+      'DTEND;TZID=Europe/Berlin:20140216T090000',
+      'DTSTAMP:20140216T120000Z',
       'UID:E41JRQX2DB4P1AQZI86BAT7NHPBHPRIIHQKA',
       'DESCRIPTION:please describe the event',
       'BEGIN:VALARM',
@@ -568,8 +579,8 @@ test_set_description_and_location_and_categories = _create_testcases(
     # today
     ('8:00 Äwesöme Event',
      _create_vevent(
-         'DTSTART;TZID=Europe/Berlin;VALUE=DATE-TIME:20140216T080000',
-         'DTEND;TZID=Europe/Berlin;VALUE=DATE-TIME:20140216T090000',
+         'DTSTART;TZID=Europe/Berlin:20140216T080000',
+         'DTEND;TZID=Europe/Berlin:20140216T090000',
          'CATEGORIES:boring meeting',
          'DESCRIPTION:please describe the event',
          'LOCATION:in the office')))
