@@ -5,11 +5,14 @@ import pytest
 from tzlocal import get_localzone as _get_localzone
 
 from khal.settings import get_config
-from khal.settings.exceptions import (CannotParseConfigFileError,
-                                      InvalidSettingsError)
-from khal.settings.utils import (config_checks, get_all_vdirs,
-                                 get_color_from_vdir, get_unique_name,
-                                 is_color)
+from khal.settings.exceptions import CannotParseConfigFileError, InvalidSettingsError
+from khal.settings.utils import (
+    config_checks,
+    get_all_vdirs,
+    get_color_from_vdir,
+    get_unique_name,
+    is_color,
+)
 
 try:
     # Available from configobj 5.1.0
@@ -158,36 +161,6 @@ default_calendar = home
             config_checks(get_config(conf_path))
 
 
-@pytest.fixture
-def metavdirs(tmpdir):
-    tmpdir = str(tmpdir)
-    dirstructure = [
-        '/cal1/public/',
-        '/cal1/private/',
-        '/cal2/public/',
-        '/cal3/public/',
-        '/cal3/work/',
-        '/cal3/home/',
-        '/cal4/cfgcolor/',
-        '/cal4/dircolor/',
-        '/cal4/cfgcolor_again/',
-        '/cal4/cfgcolor_once_more/',
-    ]
-    for one in dirstructure:
-        os.makedirs(tmpdir + one)
-    filestructure = [
-        ('/cal1/public/displayname', 'my calendar'),
-        ('/cal1/public/color', 'dark blue'),
-        ('/cal1/private/displayname', 'my private calendar'),
-        ('/cal1/private/color', '#FF00FF'),
-        ('/cal4/dircolor/color', 'dark blue'),
-    ]
-    for filename, content in filestructure:
-        with open(tmpdir + filename, 'w') as metafile:
-            metafile.write(content)
-    return tmpdir
-
-
 def test_broken_color(metavdirs):
     path = metavdirs
     newvdir = path + '/cal5/'
@@ -198,25 +171,30 @@ def test_broken_color(metavdirs):
 
 
 def test_discover(metavdirs):
-    path = metavdirs
-    vdirs = {vdir[len(path):] for vdir in get_all_vdirs(path + '/*/*')}
-    assert vdirs == {
+    test_vdirs = {
         '/cal1/public', '/cal1/private', '/cal2/public',
         '/cal3/home', '/cal3/public', '/cal3/work',
-        '/cal4/cfgcolor', '/cal4/dircolor', '/cal4/cfgcolor_again', '/cal4/cfgcolor_once_more'
+        '/cal4/cfgcolor', '/cal4/dircolor', '/cal4/cfgcolor_again',
+        '/cal4/cfgcolor_once_more',
+        '/singlecollection',
     }
+    path = metavdirs
+    assert test_vdirs == {vdir[len(path):] for vdir in get_all_vdirs(path + '/**/*/')}
+    assert test_vdirs == {vdir[len(path):] for vdir in get_all_vdirs(path + '/**/')}
+    assert test_vdirs == {vdir[len(path):] for vdir in get_all_vdirs(path + '/**/*')}
 
 
 def test_get_unique_name(metavdirs):
     path = metavdirs
-    vdirs = list(get_all_vdirs(path + '/*/*'))
+    vdirs = list(get_all_vdirs(path + '/**/'))
     names = []
     for vdir in sorted(vdirs):
         names.append(get_unique_name(vdir, names))
-    assert names == [
+    assert sorted(names) == sorted([
         'my private calendar', 'my calendar', 'public', 'home', 'public1',
         'work', 'cfgcolor', 'cfgcolor_again', 'cfgcolor_once_more', 'dircolor',
-    ]
+        'singlecollection',
+    ])
 
 
 def test_config_checks(metavdirs):
@@ -235,7 +213,7 @@ def test_config_checks(metavdirs):
     for cal in config['calendars']:
         config['calendars'][cal]['path'] = config['calendars'][cal]['path'][len(metavdirs):]
 
-    assert config == {
+    test_config = {
         'calendars': {
             'home': {
                 'color': None,
@@ -258,16 +236,16 @@ def test_config_checks(metavdirs):
                 'type': 'calendar',
                 'priority': 10,
             },
-            'public': {
+            'public1': {
                 'color': None,
-                'path': '/cal2/public',
+                'path': '/cal3/public',
                 'readonly': False,
                 'type': 'calendar',
                 'priority': 10,
             },
-            'public1': {
+            'public': {
                 'color': None,
-                'path': '/cal3/public',
+                'path': '/cal2/public',
                 'readonly': False,
                 'type': 'calendar',
                 'priority': 10,
@@ -314,6 +292,9 @@ def test_config_checks(metavdirs):
         'sqlite': {'path': '/tmp'},
     }
 
+    assert config['calendars'] == test_config['calendars']
+    assert config == test_config
+
 
 def test_is_color():
     assert is_color('dark blue') == 'dark blue'
